Welcome to ClientVPS Mirrors

Help for package rpart.LAD
Type: Package
Title: Least Absolute Deviation Regression Trees
Version: 0.1.3
Date: 2023-11-18
Author: Stephan Dlugosz [aut,cre]
Maintainer: Stephan Dlugosz <stephan.dlugosz@googlemail.com>
Description: Recursive partitioning for least absolute deviation regression trees. Another algorithm from the 1984 book by Breiman, Friedman, Olshen and Stone in addition to the 'rpart' package (Breiman, Friedman, Olshen, Stone (1984, ISBN:9780412048418).
License: GPL-3
NeedsCompilation: yes
Depends: R (≥ 3.6.0), Rcpp (≥ 0.12.3), rpart (≥ 3.1.0)
LinkingTo: Rcpp (≥ 0.12.3)
Encoding: UTF-8
RoxygenNote: 7.2.3
Packaged: 2023-11-18 08:58:16 UTC; sdlug
Repository: CRAN
Date/Publication: 2023-11-18 09:30:02 UTC

rpart.LAD: Least Absolute Deviation Regression Trees

Description

Recursive partitioning for least absolute deviation regression trees. Another algorithm from the 1984 book by Breiman, Friedman, Olshen and Stone in addition to the 'rpart' package (Breiman, Friedman, Olshen, Stone (1984, ISBN:9780412048418).


'rpart'-method: List of required functions for inducing 'rpart'-like LAD regression trees

Description

'rpart'-method: List of required functions for inducing 'rpart'-like LAD regression trees

Usage

LAD

Format

An object of class list of length 4.

Examples

  mystate <- data.frame(state.x77, region = state.region)
  names(mystate) <- casefold(names(mystate)) #remove mixed case

  fit <-  rpart(murder ~ ., data = mystate, minsplit = 10, method = LAD)
  plot(fit); text(fit)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.